/****************************************************************************
** Meta object code from reading C++ file 'qscxmlstatemachine.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kde-qtscxml/src/scxml/qscxmlstatemachine.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qscxmlstatemachine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QScxmlStateMachine_t {
    QByteArrayData data[48];
    char stringdata0[595];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QScxmlStateMachine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QScxmlStateMachine_t qt_meta_stringdata_QScxmlStateMachine = {
    {
QT_MOC_LITERAL(0, 0, 18), // "QScxmlStateMachine"
QT_MOC_LITERAL(1, 19, 14), // "runningChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 7), // "running"
QT_MOC_LITERAL(4, 43, 22), // "invokedServicesChanged"
QT_MOC_LITERAL(5, 66, 32), // "QVector<QScxmlInvokableService*>"
QT_MOC_LITERAL(6, 99, 15), // "invokedServices"
QT_MOC_LITERAL(7, 115, 3), // "log"
QT_MOC_LITERAL(8, 119, 5), // "label"
QT_MOC_LITERAL(9, 125, 3), // "msg"
QT_MOC_LITERAL(10, 129, 18), // "reachedStableState"
QT_MOC_LITERAL(11, 148, 8), // "finished"
QT_MOC_LITERAL(12, 157, 16), // "dataModelChanged"
QT_MOC_LITERAL(13, 174, 16), // "QScxmlDataModel*"
QT_MOC_LITERAL(14, 191, 5), // "model"
QT_MOC_LITERAL(15, 197, 20), // "initialValuesChanged"
QT_MOC_LITERAL(16, 218, 13), // "initialValues"
QT_MOC_LITERAL(17, 232, 18), // "initializedChanged"
QT_MOC_LITERAL(18, 251, 11), // "initialized"
QT_MOC_LITERAL(19, 263, 13), // "loaderChanged"
QT_MOC_LITERAL(20, 277, 23), // "QScxmlCompiler::Loader*"
QT_MOC_LITERAL(21, 301, 6), // "loader"
QT_MOC_LITERAL(22, 308, 16), // "tableDataChanged"
QT_MOC_LITERAL(23, 325, 16), // "QScxmlTableData*"
QT_MOC_LITERAL(24, 342, 9), // "tableData"
QT_MOC_LITERAL(25, 352, 5), // "start"
QT_MOC_LITERAL(26, 358, 4), // "stop"
QT_MOC_LITERAL(27, 363, 4), // "init"
QT_MOC_LITERAL(28, 368, 10), // "stateNames"
QT_MOC_LITERAL(29, 379, 8), // "compress"
QT_MOC_LITERAL(30, 388, 16), // "activeStateNames"
QT_MOC_LITERAL(31, 405, 8), // "isActive"
QT_MOC_LITERAL(32, 414, 14), // "scxmlStateName"
QT_MOC_LITERAL(33, 429, 11), // "submitEvent"
QT_MOC_LITERAL(34, 441, 12), // "QScxmlEvent*"
QT_MOC_LITERAL(35, 454, 5), // "event"
QT_MOC_LITERAL(36, 460, 9), // "eventName"
QT_MOC_LITERAL(37, 470, 4), // "data"
QT_MOC_LITERAL(38, 475, 18), // "cancelDelayedEvent"
QT_MOC_LITERAL(39, 494, 6), // "sendId"
QT_MOC_LITERAL(40, 501, 20), // "isDispatchableTarget"
QT_MOC_LITERAL(41, 522, 6), // "target"
QT_MOC_LITERAL(42, 529, 9), // "dataModel"
QT_MOC_LITERAL(43, 539, 9), // "sessionId"
QT_MOC_LITERAL(44, 549, 4), // "name"
QT_MOC_LITERAL(45, 554, 7), // "invoked"
QT_MOC_LITERAL(46, 562, 11), // "parseErrors"
QT_MOC_LITERAL(47, 574, 20) // "QVector<QScxmlError>"

    },
    "QScxmlStateMachine\0runningChanged\0\0"
    "running\0invokedServicesChanged\0"
    "QVector<QScxmlInvokableService*>\0"
    "invokedServices\0log\0label\0msg\0"
    "reachedStableState\0finished\0"
    "dataModelChanged\0QScxmlDataModel*\0"
    "model\0initialValuesChanged\0initialValues\0"
    "initializedChanged\0initialized\0"
    "loaderChanged\0QScxmlCompiler::Loader*\0"
    "loader\0tableDataChanged\0QScxmlTableData*\0"
    "tableData\0start\0stop\0init\0stateNames\0"
    "compress\0activeStateNames\0isActive\0"
    "scxmlStateName\0submitEvent\0QScxmlEvent*\0"
    "event\0eventName\0data\0cancelDelayedEvent\0"
    "sendId\0isDispatchableTarget\0target\0"
    "dataModel\0sessionId\0name\0invoked\0"
    "parseErrors\0QVector<QScxmlError>"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QScxmlStateMachine[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
      11,  188, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  129,    2, 0x06 /* Public */,
       4,    1,  132,    2, 0x06 /* Public */,
       7,    2,  135,    2, 0x06 /* Public */,
      10,    0,  140,    2, 0x06 /* Public */,
      11,    0,  141,    2, 0x06 /* Public */,
      12,    1,  142,    2, 0x06 /* Public */,
      15,    1,  145,    2, 0x06 /* Public */,
      17,    1,  148,    2, 0x06 /* Public */,
      19,    1,  151,    2, 0x06 /* Public */,
      22,    1,  154,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      25,    0,  157,    2, 0x0a /* Public */,
      26,    0,  158,    2, 0x0a /* Public */,
      27,    0,  159,    2, 0x0a /* Public */,

 // methods: name, argc, parameters, tag, flags
      28,    1,  160,    2, 0x02 /* Public */,
      28,    0,  163,    2, 0x22 /* Public | MethodCloned */,
      30,    1,  164,    2, 0x02 /* Public */,
      30,    0,  167,    2, 0x22 /* Public | MethodCloned */,
      31,    1,  168,    2, 0x02 /* Public */,
      33,    1,  171,    2, 0x02 /* Public */,
      33,    1,  174,    2, 0x02 /* Public */,
      33,    2,  177,    2, 0x02 /* Public */,
      38,    1,  182,    2, 0x02 /* Public */,
      40,    1,  185,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, QMetaType::QVariantMap,   16,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 23,   24,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,

 // methods: parameters
    QMetaType::QStringList, QMetaType::Bool,   29,
    QMetaType::QStringList,
    QMetaType::QStringList, QMetaType::Bool,   29,
    QMetaType::QStringList,
    QMetaType::Bool, QMetaType::QString,   32,
    QMetaType::Void, 0x80000000 | 34,   35,
    QMetaType::Void, QMetaType::QString,   36,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   36,   37,
    QMetaType::Void, QMetaType::QString,   39,
    QMetaType::Bool, QMetaType::QString,   41,

 // properties: name, type, flags
       3, QMetaType::Bool, 0x00495103,
      18, QMetaType::Bool, 0x00495001,
      42, 0x80000000 | 13, 0x0049510b,
      16, QMetaType::QVariantMap, 0x00495103,
       6, 0x80000000 | 5, 0x00495009,
      43, QMetaType::QString, 0x00095401,
      44, QMetaType::QString, 0x00095401,
      45, QMetaType::Bool, 0x00095401,
      46, 0x80000000 | 47, 0x00095409,
      21, 0x80000000 | 20, 0x0049510b,
      24, 0x80000000 | 23, 0x0049510b,

 // properties: notify_signal_id
       0,
       7,
       5,
       6,
       1,
       0,
       0,
       0,
       0,
       8,
       9,

       0        // eod
};

void QScxmlStateMachine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QScxmlStateMachine *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->runningChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->invokedServicesChanged((*reinterpret_cast< const QVector<QScxmlInvokableService*>(*)>(_a[1]))); break;
        case 2: _t->log((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->reachedStableState(); break;
        case 4: _t->finished(); break;
        case 5: _t->dataModelChanged((*reinterpret_cast< QScxmlDataModel*(*)>(_a[1]))); break;
        case 6: _t->initialValuesChanged((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 7: _t->initializedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->loaderChanged((*reinterpret_cast< QScxmlCompiler::Loader*(*)>(_a[1]))); break;
        case 9: _t->tableDataChanged((*reinterpret_cast< QScxmlTableData*(*)>(_a[1]))); break;
        case 10: _t->start(); break;
        case 11: _t->stop(); break;
        case 12: { bool _r = _t->init();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QStringList _r = _t->stateNames((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 14: { QStringList _r = _t->stateNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 15: { QStringList _r = _t->activeStateNames((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 16: { QStringList _r = _t->activeStateNames();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->isActive((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->submitEvent((*reinterpret_cast< QScxmlEvent*(*)>(_a[1]))); break;
        case 19: _t->submitEvent((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->submitEvent((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 21: _t->cancelDelayedEvent((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: { bool _r = _t->isDispatchableTarget((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<QScxmlInvokableService*> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScxmlDataModel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QScxmlStateMachine::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::runningChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(const QVector<QScxmlInvokableService*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::invokedServicesChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::log)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::reachedStableState)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::finished)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(QScxmlDataModel * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::dataModelChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::initialValuesChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::initializedChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(QScxmlCompiler::Loader * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::loaderChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QScxmlStateMachine::*)(QScxmlTableData * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QScxmlStateMachine::tableDataChanged)) {
                *result = 9;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScxmlDataModel* >(); break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<QScxmlError> >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<QScxmlInvokableService*> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QScxmlStateMachine *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isRunning(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isInitialized(); break;
        case 2: *reinterpret_cast< QScxmlDataModel**>(_v) = _t->dataModel(); break;
        case 3: *reinterpret_cast< QVariantMap*>(_v) = _t->initialValues(); break;
        case 4: *reinterpret_cast< QVector<QScxmlInvokableService*>*>(_v) = _t->invokedServices(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->sessionId(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isInvoked(); break;
        case 8: *reinterpret_cast< QVector<QScxmlError>*>(_v) = _t->parseErrors(); break;
        case 9: *reinterpret_cast< QScxmlCompiler::Loader**>(_v) = _t->loader(); break;
        case 10: *reinterpret_cast< QScxmlTableData**>(_v) = _t->tableData(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QScxmlStateMachine *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRunning(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setDataModel(*reinterpret_cast< QScxmlDataModel**>(_v)); break;
        case 3: _t->setInitialValues(*reinterpret_cast< QVariantMap*>(_v)); break;
        case 9: _t->setLoader(*reinterpret_cast< QScxmlCompiler::Loader**>(_v)); break;
        case 10: _t->setTableData(*reinterpret_cast< QScxmlTableData**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QScxmlStateMachine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QScxmlStateMachine.data,
    qt_meta_data_QScxmlStateMachine,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QScxmlStateMachine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QScxmlStateMachine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QScxmlStateMachine.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QScxmlStateMachine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QScxmlStateMachine::runningChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QScxmlStateMachine::invokedServicesChanged(const QVector<QScxmlInvokableService*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QScxmlStateMachine::log(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QScxmlStateMachine::reachedStableState()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QScxmlStateMachine::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QScxmlStateMachine::dataModelChanged(QScxmlDataModel * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QScxmlStateMachine::initialValuesChanged(const QVariantMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QScxmlStateMachine::initializedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QScxmlStateMachine::loaderChanged(QScxmlCompiler::Loader * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QScxmlStateMachine::tableDataChanged(QScxmlTableData * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
